/*
 * Copyright (c) 1999 The Java Apache Project.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. All advertising materials mentioning features or use of this
 *    software must display the following acknowledgment:
 *    "This product includes software developed by the Java Apache 
 *    Project. <http://java.apache.org/>"
 *
 * 4. The names "Java Apache Element Construction Set", "Java Apache ECS" and 
 *    "Java Apache Project" must not be used to endorse or promote products 
 *    derived from this software without prior written permission.
 *
 * 5. Products derived from this software may not be called 
 *    "Java Apache Element Construction Set" nor "Java Apache ECS" appear 
 *    in their names without prior written permission of the 
 *    Java Apache Project.
 *
 * 6. Redistributions of any form whatsoever must retain the following
 *    acknowledgment:
 *    "This product includes software developed by the Java Apache 
 *    Project. <http://java.apache.org/>"
 *    
 * THIS SOFTWARE IS PROVIDED BY THE JAVA APACHE PROJECT "AS IS" AND ANY
 * EXPRESSED OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE JAVA APACHE PROJECT OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Java Apache Project. For more information
 * on the Java Apache Project please see <http://java.apache.org/>.
 *
 */
package org.apache.ecs;

import java.io.OutputStream;
import java.io.PrintWriter;
import java.io.IOException;
import java.util.Hashtable;
import java.util.Enumeration;
import java.util.Vector;

/**
    This class defines a comment &lt;-- VALUE --&gt; Element.
    @version $Id: Comment.java,v 1.1.1.1 1999/04/20 01:18:57 jonbolt Exp $
    @author <a href="mailto:snagy@servletapi.com">Stephan Nagy</a>
    @author <a href="mailto:jon@clearink.com">Jon S. Stevens</a>
*/
public class Comment extends MultiPartElement
{

    /**
        private initializer.
    */
    {
        setHtmlElementType("--");
    }

	/**
		Default constructor use set* methods.
	*/
    public Comment()
    {
    }

	/**
		Create a comment object containg this element.
	*/
    public Comment(String element)
    {
        addElement(element);
    }

	/**
		Create a comment object containg this element.
	*/
    public Comment(Element element)
    {
        addElement(element);
    }
    
    /**
        Override output(OutputStream) incase any elements are in the registry.
        @param output OutputStream to write to.
    */
    public void output(OutputStream out)
    {
        if (super.v_element.size() == 0)
        {
            processOutput(out);
        }
        else
        {

            Enumeration enum = super.v_element.elements();
            String tmp = (String) this.getElementHashEntry().get("_text");
            Element element;

            while (enum.hasMoreElements())
            {
                Object obj = enum.nextElement();
                if (obj instanceof Element)
                {
                    element = (Element) obj;
                    tmp = tmp + element.toString();
                }
                else
                {
                    tmp = tmp + obj.toString();
                }
            }
            addAttribute("_text",tmp);
            processOutput(out);
        }
    }

    /**
        Override output(PrintWriter) incase any elements are in the registry.
        @param output OutputStream to write to.
    */
    public void output(PrintWriter out)
    {
        if (super.v_element.size() == 0)
        {
            processOutput(out);
        }
        else
        {
            Enumeration enum = super.v_element.elements();
            String tmp = (String) this.getElementHashEntry().get("_text");
            Element element;

            while (enum.hasMoreElements())
            {
                Object obj = enum.nextElement();
                if (obj instanceof Element)
                {
                    element = (Element) obj;
                    tmp = tmp + element.toString();
                }
                else
                {
                    tmp = tmp + (String)obj;
                }
            }
            addAttribute("_text",tmp);
            processOutput(out);
        }
    }

    /** Add the element to the designated OutputStream. */
    private void processOutput(OutputStream out)
    {
        try
        {
            Hashtable ce = (Hashtable) getElementHashEntry().clone();
            String html_content = new String();
    
            String html_tag = (String) ce.get("_tag");
            ce.remove("_tag"); // get rid of the tag
    
            html_content = (String) ce.get("_text");
            ce.remove("_text"); // get rid of the _text attribute
            out.write('<');
            out.write('!');
            out.write(alterCase(html_tag).getBytes());
            out.write(' ');
            Enumeration enum = ce.keys();
    
            while (enum.hasMoreElements())
            {
                String tag = (String) enum.nextElement();
                String value = getFilter().process((String) ce.get(tag));
                out.write(' ');
                out.write(alterCase(tag).getBytes());
                if(!value.equalsIgnoreCase(NO_ATTRIBUTE_VALUE))
                {
                    out.write('=');
                    out.write('"');
                    out.write(value.getBytes());
                    out.write('"');
                }
            }
    
            out.write(html_content.getBytes());
    
            // Not all multi-part elements need a closing tag make it optional
            if (getNeedClosingTag())
            {
                out.write(' ');
                out.write(alterCase(html_tag).getBytes());
                out.write('>');
            }
        }
        catch (IOException e)
        {
        }
    }

    /** Add element to the designated PrintWriter. */
    public void processOutput(PrintWriter pw)
    {
        Hashtable ce = (Hashtable) getElementHashEntry().clone();
        String html_content = new String();

        String html_tag = (String) ce.get("_tag");
        ce.remove("_tag"); // get rid of the tag
        html_content = (String) ce.get("_text");
        ce.remove("_text"); // get rid of the _text attribute

        pw.write('<');
        pw.write('!');
        pw.write(alterCase(html_tag));
        Enumeration enum = ce.keys();

        while (enum.hasMoreElements())
        {

            String tag = (String) enum.nextElement();
            String value = getFilter().process((String) ce.get(tag));
            pw.write(' ');
            pw.write(alterCase(tag));
            if(!value.equalsIgnoreCase(NO_ATTRIBUTE_VALUE))
            {
                pw.write('=');
                pw.write('"');
                pw.write(value);
                pw.write('"');
            }
        }

        pw.write(html_content);
        // Not all multi-part elements need a closing tag make it optional
        if (getNeedClosingTag())
        {
            pw.write(alterCase(html_tag));
            pw.write('>');
        }
    }

    /**
        Adds an Element to the element.
        @param  element Adds an Element to the element.
     */
    public Comment addElement(Element element)
    {
        addElementToRegistry(element,getFilterState());
        return(this);
    }
    /**
        Adds an Element to the element.
        @param  element Adds an Element to the element.
     */
    public Comment addElement(String element)
    {
        addElementToRegistry(element,getFilterState());
        return(this);
    }

} 